PyPoscar — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# PyPoscar

These examples demonstrate the PyPoscar module

Visualizing Clusters in Bi2Se3 Slab

Visualizing Clusters in Bi2Se3 Slab

Analyzing Radial Distribution Functions (RDF)

Analyzing Radial Distribution Functions (RDF)

Finding defects in a POSCAR file

Finding defects in a POSCAR file

Substituting Atoms in a POSCAR File

Substituting Atoms in a POSCAR File

Modifying a POSCAR File: Scaling, Supercells, and Defects

Modifying a POSCAR File: Scaling, Supercells, and Defects